Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FooExpansion ¶
type FooExpansion interface{}
type FooInterface ¶
type FooInterface interface {
Create(ctx context.Context, foo *v1alpha1.Foo, opts v1.CreateOptions) (*v1alpha1.Foo, error)
Update(ctx context.Context, foo *v1alpha1.Foo, opts v1.UpdateOptions) (*v1alpha1.Foo, error)
UpdateStatus(ctx context.Context, foo *v1alpha1.Foo, opts v1.UpdateOptions) (*v1alpha1.Foo, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.Foo, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.FooList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Foo, err error)
FooExpansion
}
FooInterface has methods to work with Foo resources.
type FoosGetter ¶
type FoosGetter interface {
Foos(namespace string) FooInterface
}
FoosGetter has a method to return a FooInterface. A group's client should implement this interface.
type NikayaV1alpha1Client ¶
type NikayaV1alpha1Client struct {
// contains filtered or unexported fields
}
NikayaV1alpha1Client is used to interact with features provided by the nikaya.arhat.dev group.
func New ¶
func New(c rest.Interface) *NikayaV1alpha1Client
New creates a new NikayaV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*NikayaV1alpha1Client, error)
NewForConfig creates a new NikayaV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *NikayaV1alpha1Client
NewForConfigOrDie creates a new NikayaV1alpha1Client for the given config and panics if there is an error in the config.
func (*NikayaV1alpha1Client) Foos ¶
func (c *NikayaV1alpha1Client) Foos(namespace string) FooInterface
func (*NikayaV1alpha1Client) RESTClient ¶
func (c *NikayaV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type NikayaV1alpha1Interface ¶
type NikayaV1alpha1Interface interface {
RESTClient() rest.Interface
FoosGetter
}
Source Files
¶
- doc.go
- foo.go
- generated_expansion.go
- nikaya_client.go